@@ -21,9 +21,9 @@ import typing as T
 
 from blueprintcompiler.language.common import GirType
 
-from .gobject_object import Object, ObjectContent
-from .common import *
 from ..gir import TemplateType
+from .common import *
+from .gobject_object import Object, ObjectContent
 from .types import ClassName, TemplateClassName
 
 
@@ -44,6 +44,13 @@ class Template(Object):
     def id(self) -> str:
         return "template"
 
+    @property
+    def signature(self) -> str:
+        if self.parent_type:
+            return f"template {self.gir_class.full_name} : {self.parent_type.gir_type.full_name}"
+        else:
+            return f"template {self.gir_class.full_name}"
+
     @property
     def gir_class(self) -> GirType:
         if isinstance(self.class_name.gir_type, ExternType):
