@@ -17,13 +17,15 @@
 #
 # SPDX-License-Identifier: LGPL-3.0-or-later
 
+from functools import cached_property
+
 from .. import gir
-from .imports import GtkDirective, Import
-from .gtkbuilder_template import Template
-from .gobject_object import Object
-from .gtk_menu import menu, Menu
 from .common import *
 from .contexts import ScopeCtx
+from .gobject_object import Object
+from .gtk_menu import Menu, menu
+from .gtkbuilder_template import Template
+from .imports import GtkDirective, Import
 
 
 class UI(AstNode):
@@ -42,7 +44,7 @@ class UI(AstNode):
         ),
     ]
 
-    @property
+    @cached_property
     def gir(self) -> gir.GirContext:
         gir_ctx = gir.GirContext()
         self._gir_errors = []
