@@ -20,21 +20,19 @@
 """ Utilities for parsing an AST from a token stream. """
 
 import typing as T
-
 from collections import defaultdict
 from enum import Enum
-from .ast_utils import AstNode
 
+from .ast_utils import AstNode
 from .errors import (
-    assert_true,
-    CompilerBugError,
     CompileError,
+    CompilerBugError,
     CompileWarning,
     UnexpectedTokenError,
+    assert_true,
 )
 from .tokenizer import Token, TokenType
 
-
 SKIP_TOKENS = [TokenType.COMMENT, TokenType.WHITESPACE]
 
 
@@ -522,8 +520,6 @@ class UseNumber(ParseNode):
             return False
 
         number = token.get_number()
-        if number % 1.0 == 0:
-            number = int(number)
         ctx.set_group_val(self.key, number, token)
         return True
 
